==> location_picker_text_field-0.0.3.tar.gz: lib/open_street_location_picker.dart <==
library open_street_location_picker;
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:flutter_typeahead/flutter_typeahead.dart';
import 'package:http/http.dart' as http;
import 'package:location_picker_text_field/search_location.dart';

import 'classes.dart';

// ignore: must_be_immutable
class LocationPicker extends StatefulWidget {
  String label;
  double? height;
  double? borderRadius;
  ValueChanged<OSMdata>? onSelect;

  LocationPicker({Key? key,required this.label,this.borderRadius,this.height}) : super(key: key);

  @override
  State<LocationPicker> createState() => _LocationPickerState();
}

late TextEditingController locationName;

class _LocationPickerState extends State<LocationPicker> {
  final GlobalKey<ScaffoldState> _scaffoldKey = GlobalKey<ScaffoldState>();

  @override
  void initState() {
    locationName = TextEditingController();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      height: widget.height ?? 50,
      child: TypeAheadField<OSMdata>(
        suggestionsCallback: (search) async{
          List<OSMdata> options = <OSMdata>[];
          var client = http.Client();
          try {
            String url = "https://nominatim.openstreetmap.org/search?q=$search&format=json&accept-language=en";
            var response = await client.get(Uri.parse(url));
            var decodedResponse = jsonDecode(utf8.decode(response.bodyBytes)) as List<dynamic>;
            options = decodedResponse
                .map((e) => OSMdata(
                displayname: e['display_name'],
                latitude: double.parse(e['lat']),
                longitude: double.parse(e['lon'])))
                .toList();
            if(options.isNotEmpty){
              options.add(const OSMdata(displayname: "Set on map", latitude: 0, longitude: 0));
            }
          } on Exception {
            //print(e);
          } finally {
            client.close();
          }
          return options;
        },
        controller: locationName,
        builder: (context, controller, focusNode) {
          return TextField(
              controller: controller,
              focusNode: focusNode,
              autofocus: true,
              decoration: InputDecoration(
                border: OutlineInputBorder(
                  borderSide: const BorderSide(width: 1.0),
                  borderRadius: BorderRadius.circular(widget.borderRadius ?? 10.0),
                ),
                contentPadding: const EdgeInsets.only(left: 12, right: 12),
                labelText: widget.label,
                suffixIcon: IconButton(
                  onPressed: (){
                    locationName.clear();
                  },
                  icon: const Icon(Icons.cancel_outlined)
                ),
              )
          );
        },
        itemBuilder: (context, OSMdata suggestion) {
          if(suggestion.displayname == "Set on map"){
            return ListTile(
              leading: const Icon(Icons.my_location,size: 22,),
              title: Text(suggestion.displayname),
              onTap: (){
                Navigator.push(context, MaterialPageRoute(builder: (context) => const SearchLocation())).then((value){
                  if(value != null){
                    if(widget.onSelect != null){
                      widget.onSelect!(OSMdata(displayname: value["address"], latitude: value["latitude"], longitude: value["longitude"]));
                    }
                  }
                  FocusScope.of(_scaffoldKey.currentContext!).unfocus();
                });
                FocusScope.of(_scaffoldKey.currentContext!).unfocus();
              },
            );
          }else{
            return ListTile(
              leading: const Icon(Icons.my_location,size: 22,),
              title: Text(suggestion.displayname),
            );
          }
        },
        onSelected: widget.onSelect,
      ),
    );
  }
}

==> location_picker_text_field-0.0.4.tar.gz: lib/open_street_location_picker.dart <==
library open_street_location_picker;
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:flutter_typeahead/flutter_typeahead.dart';
import 'package:http/http.dart' as http;
import 'package:location_picker_text_field/search_location.dart';

import 'classes.dart';

// ignore: must_be_immutable
class LocationPicker extends StatefulWidget {
  String label;
  double? height;
  double? borderRadius;
  ValueChanged<OSMdata> onSelect;
  TextEditingController controller;

  LocationPicker({Key? key,required this.label,required this.controller,required this.onSelect,this.borderRadius,this.height}) : super(key: key);

  @override
  State<LocationPicker> createState() => _LocationPickerState();
}

late TextEditingController locationName;

class _LocationPickerState extends State<LocationPicker> {
  final GlobalKey<ScaffoldState> _scaffoldKey = GlobalKey<ScaffoldState>();

  @override
  void initState() {
    locationName = TextEditingController();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return SizedBox(
      height: widget.height ?? 50,
      child: TypeAheadField<OSMdata>(
        suggestionsCallback: (search) async{
          List<OSMdata> options = <OSMdata>[];
          var client = http.Client();
          try {
            String url = "https://nominatim.openstreetmap.org/search?q=$search&format=json&accept-language=en";
            var response = await client.get(Uri.parse(url));
            var decodedResponse = jsonDecode(utf8.decode(response.bodyBytes)) as List<dynamic>;
            options = decodedResponse
                .map((e) => OSMdata(
                displayname: e['display_name'],
                latitude: double.parse(e['lat']),
                longitude: double.parse(e['lon'])))
                .toList();
            if(options.isNotEmpty){
              options.add(const OSMdata(displayname: "Set on map", latitude: 0, longitude: 0));
            }
          } on Exception {
            //print(e);
          } finally {
            client.close();
          }
          return options;
        },
        controller: locationName,
        builder: (context, controller, focusNode) {
          return TextField(
              controller: controller,
              focusNode: focusNode,
              autofocus: true,
              decoration: InputDecoration(
                border: OutlineInputBorder(
                  borderSide: const BorderSide(width: 1.0),
                  borderRadius: BorderRadius.circular(widget.borderRadius ?? 10.0),
                ),
                contentPadding: const EdgeInsets.only(left: 12, right: 12),
                labelText: widget.label,
                suffixIcon: IconButton(
                  onPressed: (){
                    locationName.clear();
                  },
                  icon: const Icon(Icons.cancel_outlined)
                ),
              )
          );
        },
        itemBuilder: (context, OSMdata suggestion) {
          if(suggestion.displayname == "Set on map"){
            return ListTile(
              leading: const Icon(Icons.my_location,size: 22,),
              title: Text(suggestion.displayname),
              onTap: (){
                Navigator.push(context, MaterialPageRoute(builder: (context) => const SearchLocation())).then((value){
                  if(value != null){
                    widget.onSelect(OSMdata(displayname: value["address"], latitude: value["latitude"], longitude: value["longitude"]));
                  }
                  FocusScope.of(_scaffoldKey.currentContext!).unfocus();
                });
                FocusScope.of(_scaffoldKey.currentContext!).unfocus();
              },
            );
          }else{
            return ListTile(
              leading: const Icon(Icons.my_location,size: 22,),
              title: Text(suggestion.displayname),
            );
          }
        },
        onSelected: widget.onSelect,
      ),
    );
  }
}
